==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/signalrservice/kotlin/inputs/SignalRNetworkACLsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.signalrservice.kotlin.inputs

import com.pulumi.azurenative.signalrservice.inputs.SignalRNetworkACLsArgs.builder
import com.pulumi.azurenative.signalrservice.kotlin.enums.ACLAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network ACLs for the resource
 * @property defaultAction Azure Networking ACL Action.
 * @property privateEndpoints ACLs for requests from private endpoints
 * @property publicNetwork Network ACL
 */
public data class SignalRNetworkACLsArgs(
    public val defaultAction: Output<Either<String, ACLAction>>? = null,
    public val privateEndpoints: Output<List<PrivateEndpointACLArgs>>? = null,
    public val publicNetwork: Output<NetworkACLArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.signalrservice.inputs.SignalRNetworkACLsArgs> {
    override fun toJava(): com.pulumi.azurenative.signalrservice.inputs.SignalRNetworkACLsArgs =
        com.pulumi.azurenative.signalrservice.inputs.SignalRNetworkACLsArgs.builder()
            .defaultAction(
                defaultAction?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .privateEndpoints(
                privateEndpoints?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .publicNetwork(publicNetwork?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [SignalRNetworkACLsArgs].
 */
@PulumiTagMarker
public class SignalRNetworkACLsArgsBuilder internal constructor() {
    private var defaultAction: Output<Either<String, ACLAction>>? = null

    private var privateEndpoints: Output<List<PrivateEndpointACLArgs>>? = null

    private var publicNetwork: Output<NetworkACLArgs>? = null

    /**
     * @param value Azure Networking ACL Action.
     */
    @JvmName("hrytatesaopnkbni")
    public suspend fun defaultAction(`value`: Output<Either<String, ACLAction>>) {
        this.defaultAction = value
    }

    /**
     * @param value ACLs for requests from private endpoints
     */
    @JvmName("ckpagyseacjrbkto")
    public suspend fun privateEndpoints(`value`: Output<List<PrivateEndpointACLArgs>>) {
        this.privateEndpoints = value
    }

    @JvmName("yeunuuplohxkctsn")
    public suspend fun privateEndpoints(vararg values: Output<PrivateEndpointACLArgs>) {
        this.privateEndpoints = Output.all(values.asList())
    }

    /**
     * @param values ACLs for requests from private endpoints
     */
    @JvmName("duxvwjcopbodcdtt")
    public suspend fun privateEndpoints(values: List<Output<PrivateEndpointACLArgs>>) {
        this.privateEndpoints = Output.all(values)
    }

    /**
     * @param value Network ACL
     */
    @JvmName("qljotsddyhqjcpce")
    public suspend fun publicNetwork(`value`: Output<NetworkACLArgs>) {
        this.publicNetwork = value
    }

    /**
     * @param value Azure Networking ACL Action.
     */
    @JvmName("vnnbfnitphbdnnsb")
    public suspend fun defaultAction(`value`: Either<String, ACLAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Azure Networking ACL Action.
     */
    @JvmName("xigehterkveuugnu")
    public fun defaultAction(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ACLAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Azure Networking ACL Action.
     */
    @JvmName("rktvgacokmxqwxax")
    public fun defaultAction(`value`: ACLAction) {
        val toBeMapped = Either.ofRight<String, ACLAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value ACLs for requests from private endpoints
     */
    @JvmName("dagunnxloixnibbw")
    public suspend fun privateEndpoints(`value`: List<PrivateEndpointACLArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateEndpoints = mapped
    }

    /**
     * @param argument ACLs for requests from private endpoints
     */
    @JvmName("okhtvfjfeqwnerug")
    public suspend
    fun privateEndpoints(argument: List<suspend PrivateEndpointACLArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PrivateEndpointACLArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.privateEndpoints = mapped
    }

    /**
     * @param argument ACLs for requests from private endpoints
     */
    @JvmName("ixlscfoeibbtkhfm")
    public suspend fun privateEndpoints(
        vararg
        argument: suspend PrivateEndpointACLArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            PrivateEndpointACLArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.privateEndpoints = mapped
    }

    /**
     * @param argument ACLs for requests from private endpoints
     */
    @JvmName("uxsfxfuhtxsrjnkx")
    public suspend fun privateEndpoints(argument: suspend PrivateEndpointACLArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PrivateEndpointACLArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.privateEndpoints = mapped
    }

    /**
     * @param values ACLs for requests from private endpoints
     */
    @JvmName("hlnggpcfqkvndcis")
    public suspend fun privateEndpoints(vararg values: PrivateEndpointACLArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateEndpoints = mapped
    }

    /**
     * @param value Network ACL
     */
    @JvmName("iyspmdtyjxtihqdn")
    public suspend fun publicNetwork(`value`: NetworkACLArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicNetwork = mapped
    }

    /**
     * @param argument Network ACL
     */
    @JvmName("aksdfywnopcnnngp")
    public suspend fun publicNetwork(argument: suspend NetworkACLArgsBuilder.() -> Unit) {
        val toBeMapped = NetworkACLArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publicNetwork = mapped
    }

    internal fun build(): SignalRNetworkACLsArgs = SignalRNetworkACLsArgs(
        defaultAction = defaultAction,
        privateEndpoints = privateEndpoints,
        publicNetwork = publicNetwork,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/signalrservice/kotlin/inputs/SignalRNetworkACLsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.signalrservice.kotlin.inputs

import com.pulumi.azurenative.signalrservice.inputs.SignalRNetworkACLsArgs.builder
import com.pulumi.azurenative.signalrservice.kotlin.enums.ACLAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network ACLs for the resource
 * @property defaultAction Azure Networking ACL Action.
 * @property privateEndpoints ACLs for requests from private endpoints
 * @property publicNetwork Network ACL
 */
public data class SignalRNetworkACLsArgs(
    public val defaultAction: Output<Either<String, ACLAction>>? = null,
    public val privateEndpoints: Output<List<PrivateEndpointACLArgs>>? = null,
    public val publicNetwork: Output<NetworkACLArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.signalrservice.inputs.SignalRNetworkACLsArgs> {
    override fun toJava(): com.pulumi.azurenative.signalrservice.inputs.SignalRNetworkACLsArgs =
        com.pulumi.azurenative.signalrservice.inputs.SignalRNetworkACLsArgs.builder()
            .defaultAction(
                defaultAction?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .privateEndpoints(
                privateEndpoints?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .publicNetwork(publicNetwork?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [SignalRNetworkACLsArgs].
 */
@PulumiTagMarker
public class SignalRNetworkACLsArgsBuilder internal constructor() {
    private var defaultAction: Output<Either<String, ACLAction>>? = null

    private var privateEndpoints: Output<List<PrivateEndpointACLArgs>>? = null

    private var publicNetwork: Output<NetworkACLArgs>? = null

    /**
     * @param value Azure Networking ACL Action.
     */
    @JvmName("manphtrmqdkaekum")
    public suspend fun defaultAction(`value`: Output<Either<String, ACLAction>>) {
        this.defaultAction = value
    }

    /**
     * @param value ACLs for requests from private endpoints
     */
    @JvmName("htcljsmjgniowsgj")
    public suspend fun privateEndpoints(`value`: Output<List<PrivateEndpointACLArgs>>) {
        this.privateEndpoints = value
    }

    @JvmName("ssedarbikdtpsqpl")
    public suspend fun privateEndpoints(vararg values: Output<PrivateEndpointACLArgs>) {
        this.privateEndpoints = Output.all(values.asList())
    }

    /**
     * @param values ACLs for requests from private endpoints
     */
    @JvmName("qwtkwjsbxfkfblot")
    public suspend fun privateEndpoints(values: List<Output<PrivateEndpointACLArgs>>) {
        this.privateEndpoints = Output.all(values)
    }

    /**
     * @param value Network ACL
     */
    @JvmName("airxsqpfcyptrwxd")
    public suspend fun publicNetwork(`value`: Output<NetworkACLArgs>) {
        this.publicNetwork = value
    }

    /**
     * @param value Azure Networking ACL Action.
     */
    @JvmName("pubmpulxgjgicfji")
    public suspend fun defaultAction(`value`: Either<String, ACLAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Azure Networking ACL Action.
     */
    @JvmName("shprhgvsvumwvwse")
    public fun defaultAction(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ACLAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Azure Networking ACL Action.
     */
    @JvmName("qrcxjeghrtqvnmqv")
    public fun defaultAction(`value`: ACLAction) {
        val toBeMapped = Either.ofRight<String, ACLAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value ACLs for requests from private endpoints
     */
    @JvmName("ufkmmqyxkrncgavk")
    public suspend fun privateEndpoints(`value`: List<PrivateEndpointACLArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateEndpoints = mapped
    }

    /**
     * @param argument ACLs for requests from private endpoints
     */
    @JvmName("attpwysxubjrvbbp")
    public suspend
    fun privateEndpoints(argument: List<suspend PrivateEndpointACLArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PrivateEndpointACLArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.privateEndpoints = mapped
    }

    /**
     * @param argument ACLs for requests from private endpoints
     */
    @JvmName("vvblkuiuhccwkhjy")
    public suspend fun privateEndpoints(
        vararg
        argument: suspend PrivateEndpointACLArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            PrivateEndpointACLArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.privateEndpoints = mapped
    }

    /**
     * @param argument ACLs for requests from private endpoints
     */
    @JvmName("eqoiotwmlfutavwm")
    public suspend fun privateEndpoints(argument: suspend PrivateEndpointACLArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PrivateEndpointACLArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.privateEndpoints = mapped
    }

    /**
     * @param values ACLs for requests from private endpoints
     */
    @JvmName("adhdpoekkmnqdoag")
    public suspend fun privateEndpoints(vararg values: PrivateEndpointACLArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateEndpoints = mapped
    }

    /**
     * @param value Network ACL
     */
    @JvmName("qgwscrainhbujfwu")
    public suspend fun publicNetwork(`value`: NetworkACLArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicNetwork = mapped
    }

    /**
     * @param argument Network ACL
     */
    @JvmName("iesdxlfsfsbvifie")
    public suspend fun publicNetwork(argument: suspend NetworkACLArgsBuilder.() -> Unit) {
        val toBeMapped = NetworkACLArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publicNetwork = mapped
    }

    internal fun build(): SignalRNetworkACLsArgs = SignalRNetworkACLsArgs(
        defaultAction = defaultAction,
        privateEndpoints = privateEndpoints,
        publicNetwork = publicNetwork,
    )
}
